from typing import List, Optional

from polyaxon._connections import V1Connection, V1ConnectionResource
from polyaxon._contexts import paths as ctx_paths
from polyaxon._local_process import process_types
from polyaxon._runner.converter import BaseConverter


class MountsMixin(BaseConverter):
    @classmethod
    def _get_mount_from_store(
        cls,
        store: V1Connection,
    ):
        pass

    @classmethod
    def _get_mount_from_resource(
        cls,
        resource: V1ConnectionResource,
    ):
        pass

    @classmethod
    def _get_volume(
        cls,
        mount_path: str,
        host_path: Optional[str] = None,
        read_only: Optional[bool] = None,
    ):
        pass

    @classmethod
    def _get_docker_context_mount(cls):
        pass

    @classmethod
    def _get_auth_context_mount(
        cls,
        read_only: Optional[bool] = None,
        run_path: Optional[str] = None,
    ):
        pass

    @classmethod
    def _get_artifacts_context_mount(
        cls,
        read_only: bool = False,
        run_path: Optional[str] = None,
    ):
        pass

    @classmethod
    def _get_connections_context_mount(
        cls,
        name: str,
        mount_path: str,
        run_path: str,
    ):
        pass

    @classmethod
    def _get_shm_context_mount(cls):
        """
        Mount a tmpfs volume to /dev/shm.
        This will set /dev/shm size to half of the RAM of node.
        By default, /dev/shm is very small, only 64MB.
        Some experiments will fail due to lack of share memory,
        such as some experiments running on Pytorch.
        """
        pass

    @classmethod
    def _get_mounts(
        cls,
        use_auth_context: bool,
        use_docker_context: bool,
        use_shm_context: bool,
        use_artifacts_context: bool,
        run_path: Optional[str] = None,
    ) -> List:
        return []



from typing import Dict, List, Optional, Tuple, Union

from clipped.compact.pydantic import Field

from polyaxon._schemas.base import BaseSchemaModel


class V1EnvVar(BaseSchemaModel):
    __root__: Union[Tuple[str, str], Dict[str, str]]

    def to_cmd(self):
        if isinstance(self.__root__, tuple):
            value = self.__root__
        else:
            value = self.__root__.items()
        return [f"{value[0]}={value[1]}"]


class V1Container(BaseSchemaModel):
    name: Optional[str]
    command: Optional[List[str]]
    args: Optional[List[str]]
    env: Optional[List[V1EnvVar]]
    working_dir: Optional[str] = Field(alias="workingDir")

    def get_cmd_args(self):
        cmd_args = ["run", "--rm"]
        for env in self.env:
            cmd_args += ["-e"] + env.to_cmd()
        if self.working_dir:
            cmd_args += ["-w", self.working_dir]
        if self.command:
            cmd_args += ["--entrypoint", self.command[0]]
        cmd_args += [self.image]
        if self.command:
            cmd_args += self.command[1:]
        if self.args:
            cmd_args += self.args
        return cmd_args



import datetime

from typing import List, Optional

from clipped.compact.pydantic import StrictStr
from clipped.config.schema import BaseAllowSchemaModel
from clipped.types.uuids import UUIDStr

from polyaxon._sdk.schemas.v1_settings_catalog import V1SettingsCatalog


class V1PresetSettings(BaseAllowSchemaModel):
    projects: Optional[List[V1SettingsCatalog]]
    runs: Optional[List[V1SettingsCatalog]]


class V1Preset(BaseAllowSchemaModel):
    uuid: Optional[UUIDStr]
    name: Optional[StrictStr]
    description: Optional[StrictStr]
    tags: Optional[List[StrictStr]]
    created_at: Optional[datetime.datetime]
    updated_at: Optional[datetime.datetime]
    live_state: Optional[int]
    content: Optional[StrictStr]
    settings: Optional[V1PresetSettings]



from polyaxon._flow import V1RunKind
from polyaxon._local_process.converter.converters.job import JobConverter
from polyaxon._local_process.converter.converters.service import ServiceConverter

CONVERTERS = {
    V1RunKind.JOB: JobConverter,
    V1RunKind.SERVICE: ServiceConverter,
}



from polyaxon import settings
from polyaxon._client.client import PolyaxonClient
from polyaxon._schemas.client import ClientConfig
from polyaxon._utils.fqn_utils import split_owner_team_space


class ClientMixin:
    @property
    def client(self):
        if self._client:
            return self._client
        self._client = PolyaxonClient()
        return self._client

    def reset_client(self, **kwargs):
        if not settings.CLIENT_CONFIG.in_cluster:
            self._client = PolyaxonClient(
                ClientConfig.patch_from(settings.CLIENT_CONFIG, **kwargs)
            )

    @property
    def owner(self) -> str:
        return self._owner

    @property
    def team(self):
        return self._team

    @property
    def project(self) -> str:
        return self._project

    def set_project(self, project: str):
        self._project = project

    def set_owner(self, owner: str):
        owner, team = split_owner_team_space(owner)
        self._owner = owner
        self._team = team



from typing import Optional

from clipped.compact.pydantic import Field, StrictInt

from polyaxon._schemas.base import BaseSchemaModel


class IntervalsConfig(BaseSchemaModel):
    compatibility_check: Optional[StrictInt] = Field(alias="compatibilityCheck")



from typing import Optional

from clipped.compact.pydantic import StrictStr
from clipped.config.schema import BaseAllowSchemaModel


class V1User(BaseAllowSchemaModel):
    username: Optional[StrictStr]
    email: Optional[StrictStr]
    name: Optional[StrictStr]
    kind: Optional[StrictStr]
    theme: Optional[int]
    organization: Optional[StrictStr]
